@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: FWWindow.cpp,v 1.217 2007/02/17 19:13:54 vkurland Exp $
+  $Id: FWWindow.cpp,v 1.220 2007/07/07 05:39:33 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -27,6 +27,7 @@
 #include "config.h"
 #include "global.h"
 #include "utils.h"
+#include "utils_no_qt.h"
 
 #include "FWWindow.h"
 #include "ObjectManipulator.h"
@@ -749,12 +750,19 @@ bool FWWindow::editingLibrary()
     return (rcs!=NULL && 
             ( rcs->getFileName().findRev(".fwl",-1)!=-1) );
 }
+
 void FWWindow::toolsDiscoveryDruid()
 {
    DiscoveryDruid druid(this); 
    druid.exec();
 }
 
+void FWWindow::importPolicy()
+{
+    DiscoveryDruid druid(this, true); 
+   druid.exec();
+}
+
 void FWWindow::load(QWidget *dialogs_parent)
 {
     if (fwbdebug) qDebug("FWWindow::load(): start");
@@ -1709,6 +1717,7 @@ bool FWWindow::exportLibraryTest(list<FWObject*> &selectedLibs)
     }
     return true;
 }
+
 void FWWindow::exportLibraryTo(QString fname,list<FWObject*> &selectedLibs, bool rof)
 {
     QApplication::setOverrideCursor( QCursor( Qt::WaitCursor) );
@@ -2095,13 +2104,17 @@ void FWWindow::reopenFirewall()
 // let the GUI process events to display new tab(s)
     QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput,1000);
 
-    sb->message( tr("Building NAT view...") );
-    QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput,100);
-    if (fwbdebug)  qDebug("FWWindow::reopenFirewall()   adding NAT tab");
+    if (Resources::getTargetCapabilityBool(visibleFirewall->getStr("platform"),
+                                           "supports_nat"))
+    {
+        sb->message( tr("Building NAT view...") );
+        QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput,100);
+        if (fwbdebug)  qDebug("FWWindow::reopenFirewall()   adding NAT tab");
 
-    NAT *nat  = NAT::cast(visibleFirewall->getFirstByType(NAT::TYPENAME));
-    ruleSets->addTab( rsv=new NATView(nat,NULL) , tr("NAT") );
-    ruleSetViews[nat]=rsv;
+        NAT *nat  = NAT::cast(visibleFirewall->getFirstByType(NAT::TYPENAME));
+        ruleSets->addTab( rsv=new NATView(nat,NULL) , tr("NAT") );
+        ruleSetViews[nat]=rsv;
+    }
 
 // let the GUI process events to display new tab
     QApplication::eventLoop()->processEvents(QEventLoop::ExcludeUserInput,1000);
