@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: IPv4Dialog.cpp,v 1.27 2006/05/13 06:53:05 vkurland Exp $
+  $Id: IPv4Dialog.cpp,v 1.28 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -129,6 +129,10 @@ void IPv4Dialog::changed()
 void IPv4Dialog::validate(bool *res)
 {
     *res=true;
+
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
+
     IPv4 *s = dynamic_cast<IPv4*>(obj);
     assert(s!=NULL);
     try
@@ -172,13 +176,6 @@ void IPv4Dialog::libChanged()
 
 void IPv4Dialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
-    bool res=true;
-    validate( &res );
-    if (!res) return;
-
     IPv4 *s = dynamic_cast<IPv4*>(obj);
     assert(s!=NULL);
 
