@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: PhysicalAddressDialog.cpp,v 1.19 2006/05/13 06:53:05 vkurland Exp $
+  $Id: PhysicalAddressDialog.cpp,v 1.20 2007/04/14 00:18:43 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -93,6 +93,9 @@ void PhysicalAddressDialog::changed()
 void PhysicalAddressDialog::validate(bool *res)
 {
     *res=true;
+
+    if (!isTreeReadWrite(this,obj)) { *res=false; return; }
+    if (!validateName(this,obj,obj_name->text())) { *res=false; return; }
 }
 
 void PhysicalAddressDialog::isChanged(bool *res)
@@ -107,9 +110,6 @@ void PhysicalAddressDialog::libChanged()
 
 void PhysicalAddressDialog::applyChanges()
 {
-    if (!isTreeReadWrite(this,obj)) return;
-    if (!validateName(this,obj,obj_name->text())) return;
-
     physAddress *s = dynamic_cast<physAddress*>(obj);
     assert(s!=NULL);
 
