@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.109 2007/08/26 03:07:05 vkurland Exp $
+  $Id: instDialog.cpp,v 1.112 2007/11/02 15:14:41 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -571,12 +571,16 @@ QString instDialog::getFullPath(instConf &cnf, const QString &file )
     else return file;
 }
 
-bool instDialog::doInstallPage()
+bool instDialog::doInstallPage(Firewall* f)
 {
     if (fwbdebug) qDebug("instDialog::doInstallPage");
     
 /* change of the page when flag ready is 'true' means we should start
  * operation */
+    cnf.fwobj = f;
+
+    if (fwbdebug) qDebug(QString("instDialog::doInstallPage: firewall: %1")
+                         .arg(f->getName().c_str()));
 
     cnf.incremental = dlg->incr->isChecked();
     cnf.dry_run     = dlg->test->isChecked();
@@ -584,6 +588,14 @@ bool instDialog::doInstallPage()
     cnf.backup      = !cnf.backup_file.isEmpty();
     cnf.save_diff   = dlg->saveDiff->isChecked();
     cnf.saveStandby = dlg->saveStandby->isChecked();
+
+/* Alternative address:
+    - first, check dialog. User could have overriden it using dialog
+    - then check firewall options, user could have set it in the "Install"
+      tab of firewall settings dialog
+    - last, if all overrides are empty, take it from the management interface
+ */
+
     QString aaddr    = dlg->altAddress->text();
     if (!aaddr.isEmpty())
     {
@@ -592,8 +604,26 @@ bool instDialog::doInstallPage()
  * resolved ( Putty session name does not have to be in DNS at all ).
  */
         cnf.maddr = aaddr;
+        if (fwbdebug)
+            qDebug(
+                QString("instDialog::doInstallPage: alternative address %1")
+                .arg(aaddr));
+    
     } else
-        cnf.maddr = cnf.fwobj->getManagementAddress().toString().c_str();
+    {
+        FWOptions  *fwopt = cnf.fwobj->getOptionsObject();
+        aaddr = fwopt->getStr("altAddress").c_str();
+        if (!aaddr.isEmpty())
+            cnf.maddr = aaddr;
+        else
+            cnf.maddr = 
+                cnf.fwobj->getManagementAddress().toString().c_str();
+    }
+
+    if (fwbdebug)
+        qDebug(
+            QString("instDialog::doInstallPage: management address: %1")
+            .arg(cnf.maddr));
 
 //        cnf.maddr         = altAddress->text();
     cnf.user          = dlg->uname->text();
@@ -634,8 +664,7 @@ bool instDialog::doInstallPage()
             .arg(cnf.fwobj->getName().c_str()).latin1() );
         return false;
     }
-    if ((cnf.maddr == "" || cnf.maddr == "0.0.0.0") &&
-        dlg->altAddress->text().isEmpty())
+    if ((cnf.maddr == "" || cnf.maddr == "0.0.0.0"))
     {
         addToLog(
             QObject::tr("Management interface does not have IP address, can not communicate with the firewall.") );
@@ -1187,8 +1216,9 @@ void instDialog::continueRun()
 #ifdef _WIN32
             args.push_back(ssh);
 
-            if (!cnf.user.isEmpty() &&
-                ssh.find(QString("plink.exe"),0,false)!=-1) args.push_back("-ssh");
+            if (!cnf.user.isEmpty() && 
+                ssh.find(QString("plink.exe"),0,false)!=-1)
+                args.push_back("-ssh");
 
             args.push_back("-pw");
             args.push_back(cnf.pwd);
@@ -2085,7 +2115,7 @@ bool instDialog::runInstall(Firewall * fw)
     else
     {
         if (fwbdebug) qDebug("build-in installer");
-        return doInstallPage();
+        return doInstallPage(fw);
     }
     return true;
 }
@@ -2154,12 +2184,12 @@ void instDialog::installSelected()
     
     if (opListIterator==opList.begin() && batchInstall->isChecked())
     {
+        // check if this is PIX and if we use custom
+        // install script, set flags fPix and fCustInst accordingly
         analyseInstallQueue(fPix,fCustInst);
-        
     }
     while ( opListIterator!=opList.end())
     {
-    
         currentSaveButton->setEnabled(true);
         currentProgressBar->reset();
         currentProgressBar->setTotalSteps(100);
@@ -2176,7 +2206,6 @@ void instDialog::installSelected()
         appendRich("\n");
         //qApp->processEvents();
         
-    
         if (testFirewall(*opListIterator))
         {
             opListMapping[*opListIterator]->setText(1,tr("Installing ..."));
@@ -2190,9 +2219,9 @@ void instDialog::installSelected()
             else
             { // buildin installer
                 if (fwbdebug) qDebug("buildin installer");
-                // Show options dialog
-                if (!batchInstall->isChecked() ||
-                    opListIterator==opList.begin())
+                // Show options dialog: if batch install, show it only at the beginning,
+                // otherwise show it for every firewall on the list.
+                if (!batchInstall->isChecked() || opListIterator==opList.begin())
                 {
                     if (dlg) 
                     {
@@ -2203,17 +2232,12 @@ void instDialog::installSelected()
                     prepareInstallerOptions();
                     
                     if (batchInstall->isChecked())
-                    {
                         dlg=new instBatchOptionsDialog(this, &cnf);
-                    }
                     else
-                    {
                         dlg=new instOptionsDialog(this, &cnf);
-                    }
                     
                     if (dlg->exec()==QDialog::Rejected)
                     {
-                        
                         delete dlg;
                         dlg=NULL;
 
@@ -2233,9 +2257,10 @@ void instDialog::installSelected()
                             //if (opList.end()!=opListIterator && batchInstall->isChecked())
                             //    showPage(page(2));
                             return;
-                            
                         }
                     }
+                    // clear aternative address in the dialog if this is batch install.
+                    if (batchInstall->isChecked()) dlg->altAddress->setText("");
                     setTitle(page(1),
                        QObject::tr("Installing policy rules on firewall '%1'.").arg(
                                  (*opListIterator)->getName().c_str() ));
@@ -2251,9 +2276,7 @@ void instDialog::installSelected()
                         if (opList.end()!=opListIterator && batchInstall->isChecked())
                             showPage(page(2));
                         return;
-                        
                     }
-
                     return;
                 }
             }
@@ -2461,9 +2484,6 @@ void instDialog::analyseInstallQueue(bool &fPix, bool &fCustInst)
         fPix = fPix || f->getStr("platform")=="pix" || f->getStr("platform")=="fwsm" || f->getStr("platform")=="iosacl";
         fCustInst =  fCustInst && !( pis->getCommand()=="" );
         
-        if (cnf.fwobj==NULL && !fCustInst)
-            cnf.fwobj=f;
-        
         if (fwbdebug)
         {
             qDebug(QString("f:")+f->getName().c_str());
