@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_pf_writers.cpp,v 1.25 2007/07/14 21:08:43 vkurland Exp $
+  $Id: PolicyCompiler_pf_writers.cpp,v 1.26 2007/12/09 03:27:35 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -781,13 +781,14 @@ bool PolicyCompiler_pf::PrintRule::processNext()
             {
                 if (not_the_first) compiler->output << ",";
 
-                compiler->output << " max-src-nodes "
-                                 << ruleopt->getInt("pf_max_src_nodes");
+                if (ruleopt->getInt("pf_max_src_nodes") > 0)
+                    compiler->output << " max-src-nodes "
+                                     << ruleopt->getInt("pf_max_src_nodes");
+
                 if (ruleopt->getInt("pf_max_src_states")>0)
-                {
                     compiler->output << ", max-src-states "
                                      << ruleopt->getInt("pf_max_src_states");
-                }
+
                 not_the_first = true;
             }
 
